<?php
// ----------------------------------------------------------------------
// Copyright (c) 2002-2003 Shawn McKenzie
// http://spidean.mckenzies.net
// ----------------------------------------------------------------------
// LICENSE
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please visit http://www.gnu.org/copyleft/gpl.html
// ----------------------------------------------------------------------

define('AUTOTHEME_API_LOADED', true);

define('STARTPHP', str_replace('&lt;', '<', '&lt;?php'));
define('ENDPHP', str_replace('&gt;', '>', '?&gt;'));

function atInit($atdir, $thename)
{
    $incdir = $atdir."includes/";
    $platform = atGetPlatform();
    $platformdir = $incdir."$platform/";
    
    include_once($incdir."phpFuncs.php");
    include_once($platformdir."atAPI.php");
    include_once($platformdir."atFuncs.php");

    $platformconfig = atPlatformInit($atdir, $thename);
    extract($platformconfig);

    if (@file_exists(WHERE_IS_PERSO."themes/$thename/theme.cfg")) {
        $multipath = WHERE_IS_PERSO;
    }
    else {
        $multipath = "";
    }
    $themepath = $multipath."themes/$thename/";
    $imagepath = $themepath."images/";

    atLoadAutoConfig($atdir);
    atLoadThemeConfig($themepath);

    atAutoSetVar("atdir", $atdir);
    atAutoSetVar("incdir", $incdir);
    atAutoSetVar("platform", $platform);
    atAutoSetVar("platformdir", $platformdir);

    atThemeSetVar("thename", $thename);
    atThemeSetVar("themepath", $themepath);
    atThemeSetVar("imagepath", $imagepath);
    
    atThemeLangLoad($themepath);
    atModLangLoad('user');

    atCommandLoad();

    atLoadRunningConfig();
}

function atLoadRunningConfig()
{
    $globalconfig = atGetGlobalConfig();
    extract($globalconfig);

    $modname = atGetModName();
    $modtemplate = atTemplateGetType($template);

    atRunningSetVar("command", atGetCommands());

    atRunningSetVar("atdir", $atdir);
    atRunningSetVar("incdir", $incdir);
    atRunningSetVar("platform", $platform);
    atRunningSetVar("platformdir", $platformdir);
    atRunningSetVar("thename", $thename);
    atRunningSetVar("themepath", $themepath);
    atRunningSetVar("imagepath", $imagepath);
    atRunningSetVar("imgpath", $imagepath);
    atRunningSetVar("modname", $modname);
    atRunningSetVar("modtemplate", $modtemplate);
    atRunningSetVar("language", atGetLang());
    atRunningSetVar("modtype", atGetModType());
    atRunningSetVar("username", atGetUserName());
    atRunningSetVar("is_loggedin", atIsLoggedIn());
    atRunningSetVar("is_admin", atIsAdminUser());
    atRunningSetVar("is_home", atIsHomePage());

    /* 1.7 cfg */
    if (isset($template[$modtemplate]['default'])) {
        $modops = "default";
        $template = array_merge($template['default'], $template[$modtemplate][$modops]);
        $blockdisplay = array_merge($blockdisplay['default'], $blockdisplay[$modtemplate][$modops]);
        $style = array_merge($style['default'], $style[$modtemplate][$modops]);
    }
    /* 1.0 cfg */
    elseif (isset($template[$modtemplate])) {
        $template = array_merge($template['default'], $template[$modtemplate]);
        $blockdisplay = array_merge($blockdisplay['default'], $blockdisplay[$modtemplate]);
        $style = array_merge($style['default'], $style[$modtemplate]);
    }
    /* No custom module */
    elseif (!isset($template[$modtemplate])) {
        $template = $template['default'];
        $blockdisplay = $blockdisplay['default'];
        $style = $style['default'];
    }
    extract($style);

    atRunningSetVar("logoimg", $logoimg);
    atRunningSetVar("bgcolor1", $color1);
    atRunningSetVar("bgcolor2", $color2);
    atRunningSetVar("bgcolor3", $color3);
    atRunningSetVar("bgcolor4", $color4);
    atRunningSetVar("textcolor1", $color5);
    atRunningSetVar("textcolor2", $color6);
    atRunningSetVar("tblcolor1", $color7);
    atRunningSetVar("tblcolor2", $color8);
    atRunningSetVar("tblcolor3", $color9);
    atRunningSetVar("tblcolor4", $color10);
    atRunningSetVar("striphead", $striphead);

    $runningconfig = compact(
        "template",
        "blockdisplay",
        "style",
        "blocktemplate",
        "themeversion",
        "autoblock",
        "autolang"
    );

    atRunningMultiSetVars($runningconfig);
}

function atTemplateGetType($template)
{
    if (atIsHomePage()) {
        if (isset($template['pnHome'])) {
            $type = "pnHome";
        }
        if (isset($template['nukeHome'])) {
            $type = "nukeHome";
        }
        if (isset($template['*HomePage'])) {
            $type = "*HomePage";
        }
    }
    if (atGetModType() == "admin") {
        if (isset($template['pnAdmin'])) {
            $type = "pnAdmin";
        }
        if (isset($template['nukeAdmin'])) {
            $type = "nukeAdmin";
        }
        if (isset($template['*AdminPages'])) {
            $type = "*AdminPages";
        }
    }
    if (atGetModType() == "user") {
        if (isset($template['pnUser'])) {
            $type = "pnUser";
        }
        if (isset($template['nukeUser'])) {
            $type = "nukeUser";
        }
        if (isset($template['*UserPages'])) {
            $type = "*UserPages";
        }
    }
    if (!isset($type)) {
        $type = atGetModName();
    }
    return $type;
}

function atGetCommands()
{
    $globalconfig = atGetGlobalConfig();
    extract($globalconfig);

    if (atIsLoggedIn()) {
        $result = array_merge(
            $command['loggedin'],
            $compatcmd['loggedin'],
            $extracmd['loggedin'],
            $autocmd['loggedin']
        );
    }
    else {
        $result = array_merge(
            $command['anonymous'],
            $compatcmd['anonymous'],
            $extracmd['anonymous'],
            $autocmd['anonymous']
        );
    }
    if (atIsAdminUser()) {
        $result = array_merge(
            $result,
            $command['admin'],
            $compatcmd['admin'],
            $extracmd['admin'],
            $autocmd['admin']
        );
    }
    $command = array_merge(
        $command['all'],
        $compatcmd['all'],
        $extracmd['all'],
        $autocmd['all'],
        $result
    );

    return $command;
}

function atCommandLoad()
{
    $globalconfig = atGetGlobalConfig();
    extract($globalconfig);

    include($incdir."commands.php");
    include($platformdir."atCommands.php");

    $result['admin'] = array_merge(
            $command['admin'],
            $compatcmd['admin'],
            $autocmd['admin']
        );
    $result['all'] = array_merge(
            $command['all'],
            $compatcmd['all'],
            $autocmd['all']
        );
    $result['anonymous'] = array_merge(
            $command['anonymous'],
            $compatcmd['anonymous'],
            $autocmd['anonymous']
        );
    $result['loggedin'] = array_merge(
            $command['loggedin'],
            $compatcmd['loggedin'],
            $autocmd['loggedin']
        );

    atAutoSetVar("command", $result);

    return $result;
}

function atCommandBuild($commands, $prefix="")
{
    if (!$prefix) {
        $prefix = strtolower(atGetModName());
    }
    atRunningSetVar($prefix, $commands);
    foreach ($commands as $key => $val) {
        atCommandAdd("$prefix:$key", 'echo $'.$prefix.'["'.$key.'"];');
    }
}

function atCommandAdd($name, $command)
{
    $GLOBALS['AT_RUNNING']['command'][$name] = $command;
}

function atCommandReplace($tmpcontent, $commands)
{
    $runningconfig = atGetRunningConfig();
    extract($runningconfig);
    
    foreach ($commands as $cmd => $action) {
        $search = array(
            "<!-- [$cmd] -->",
            "{".$cmd."}",
        );

        $replace = array(
            STARTPHP." $action ".ENDPHP,
            STARTPHP." $action ".ENDPHP,
        );

        $tmpcontent = str_replace($search, $replace, $tmpcontent);
    }
    return $tmpcontent;
}

function atTemplateRead($filename)
{
	$temp = @file_get_contents($filename);
	return $temp;
}

function atTemplatePrep($filename, $striphead=1)
{
    $HTML = atTemplateRead($filename);
    if ($striphead) {
        $HTML = spliti('\<\/head\>', $HTML);
    }
    else {
        $HTML = spliti('\<head\>', $HTML);
    }
    if (isset($HTML[1])) {
        $HTML = $HTML[1];
    }
    else {
        $HTML = $HTML[0];
    }
    $HTML = spliti('\<\/body\>', $HTML);
    $HTML = trim($HTML[0]);

    return $HTML;
}

function atTemplateSplit($content, $spliton)
{
    $parts = preg_split("/(\<\!-- \[|{)$spliton(}|\] --\>)/", $content);

    return $parts;
}

function atTemplateDisplay($tmpcontent)
{
    $runningconfig = atGetRunningConfig();
    extract($runningconfig);

    eval(ENDPHP.$tmpcontent);
}

function atThemeHeader()
{
 	atThemeAddHeader();

    $runningconfig = atGetRunningConfig();
    extract($runningconfig);

    $file = $template['main'];

    $HTML = atTemplatePrep($themepath.$file, $striphead);
    $HTML = atTemplateSplit($HTML, "modules");
	$output = atCommandReplace($HTML[0], $command);
    $output = $head.$output."<div id=\"$modname\" class=\"module\">";
    atTemplateDisplay($output);
}

function atThemeFooter()
{
	atThemeAddFooter();

    $runningconfig = atGetRunningConfig();
    extract($runningconfig);

    $file = $template['main'];

    $HTML = atTemplatePrep($themepath.$file);
    $HTML = atTemplateSplit($HTML, "modules");
    $output = atCommandReplace($HTML[1], $command);
    if ($output) {
        $output = "</div>".$output;
    }
    $output = $output.$footer;
    atTemplateDisplay($output);
}

function atNewsSummary($text, $url, $html)
{
    $cmd = compact("text", "url", "html");
    foreach ($cmd as $type => $namesarray) {
        foreach ($namesarray as $name => $val) {
            $newcmd["$type:$name"] = $val;
        }
    }
    atCommandBuild($newcmd);
    
    $runningconfig = atGetRunningConfig();
    extract($runningconfig);

    if (!isset($summary_count)) {
        static $summary_count = "";
    }
    $summary_count ++;

    if ($template['altsummary'] && $template['summary1'] && $template['summary2']) {
        if ($summary_count % 2 == 0) {
            $file = $template['summary1'];
        }
        else {
            $file = $template['summary2'];
        }
    }
    else {
        $file = $template['summary'];
    }
    $HTML = atTemplateRead($themepath.$file);
    $HTML = atTemplatePrep($themepath.$file);
    $output = atCommandReplace($HTML, $command);
    atTemplateDisplay($output);
}

function atNewsArticle($text, $url, $html)
{
    $cmd = compact("text", "url", "html");
    foreach ($cmd as $type => $namesarray) {
        foreach ($namesarray as $name => $val) {
            $newcmd["$type:$name"] = $val;
        }
    }
    atCommandBuild($newcmd);
    
    $runningconfig = atGetRunningConfig();
    extract($runningconfig);

    $file = $template['article'];

    $HTML = atTemplateRead($themepath.$file);
    $HTML = atTemplatePrep($themepath.$file);
    $output = atCommandReplace($HTML, $command);
    atTemplateDisplay($output);
}

function atThemeBlock($block)
{
    $language = atGetLang();
    $imagepath = atRunningGetVar("imagepath");

    $title = trim(strip_tags($block['title'], ""));
    $titleimage = strtolower(preg_replace("^\W|_^", "", $title));

    if (@file_exists($imagepath."$language/$titleimage.gif")) {
        $block['title'] = "<img src=\"$imagepath"."$language/$titleimage.gif\" border=\"0\" alt=\"$title\">";
    }
    elseif (@file_exists($imagepath."$language/$titleimage.jpg")) {
        $block['title'] = "<img src=\"$imagepath"."$language/$titleimage.jpg\" border=\"0\" alt=\"$title\">";
    }
    elseif (@file_exists($imagepath."$language/$titleimage.png")) {
        $block['title'] = "<img src=\"$imagepath"."$language/$titleimage.png\" border=\"0\" alt=\"$title\">";
    }
    atCommandBuild($block, "block");

    $runningconfig = atGetRunningConfig();
    extract($runningconfig);

    $location = $block['position'];

    if ($block['force']) {
    	$display = 1;
    }
    else {
    	$display = 0;
    }
    switch ($location) {
		case 'l':
        if ($blockdisplay['left']) {
			$display = 1;
        }
        $file = $template['leftblock'];
        break;

        case 'r':
        if ($blockdisplay['right']) {
        	$display = 1;
        }
        $file = $template['rightblock'];
        break;

        case 'c':
        if ($blockdisplay['center']) {
            $display = 1;
        }
        $file = $template['centerblock'];
        break;

        default:
        if (is_array($autoblock) && array_key_exists($location, $autoblock)) {
            $ablock = $autoblock[$location];
            if ($blockdisplay[$ablock]) {
                $display = 1;
            }
        	$file = $template[$autoblock[$location]."block"];
        }
        break;
    }
    if (isset($blocktemplate[$title])) {
		$file = $blocktemplate[$title];
    }
    if ($display) {
        $HTML = atTemplateRead($themepath.$file);
        $HTML = atTemplatePrep($themepath.$file);
        $output = atCommandReplace($HTML, $command);
        atTemplateDisplay($output);
    }
}

function atLoadAutoConfig($path)
{
	// Include default
    @include("modules/Blocks/autoblock.cfg");
    @include("admin/modules/autoblock.cfg");
    // Include theme specific
    @include("themes/$thename/autoblock.cfg");
    // Include AutoTheme specific
    @include("modules/AutoTheme/autotheme.cfg");

    $autoconfig = compact("autoblock");

    atAutoMultiSetVars($autoconfig);
}

function atGetAutoConfig()
{
    if (isset($GLOBALS['AT_AUTO'])) {
        return $GLOBALS['AT_AUTO'];
    }
    else {
        return false;
    }
}

function atAutoMultiSetVars($vars)
{
    foreach ($vars as $name => $val) {
        atAutoSetVar($name, $val);
    }
}

function atAutoSetVar($name, $val)
{
	$GLOBALS['AT_AUTO'][$name] = $val;
}

function atAutoGetVar($var)
{
    return $GLOBALS['AT_AUTO'][$var];
}

function atLoadThemeConfig($path)
{
    include($path."theme.cfg");

    $themeconfig = compact("template", "blockdisplay", "style", "blocktemplate", "themeversion");

    atThemeMultiSetVars($themeconfig);
}

function atGetThemeConfig()
{
    return $GLOBALS['AT_THEME'];
}

function atThemeMultiSetVars($vars)
{
    foreach ($vars as $name => $val) {
        atThemeSetVar($name, $val);
    }
}

function atThemeSetVar($name, $val)
{
    $GLOBALS['AT_THEME'][$name] = $val;
}

function atThemeGetVar($var)
{
    return $GLOBALS['AT_THEME'][$var];
}

function atGetRunningConfig()
{
    return $GLOBALS['AT_RUNNING'];
}

function atRunningMultiSetVars($vars)
{
    foreach ($vars as $name => $val) {
        atRunningSetVar($name, $val);
    }
}

function atRunningSetVar($name, $val)
{
     $GLOBALS['AT_RUNNING'][$name] = $val;
}

function atRunningGetVar($var)
{
    return $GLOBALS['AT_RUNNING'][$var];
}

function atGetGlobalConfig()
{
    $autoconfig = $themeconfig = array();

    if (isset($GLOBALS['AT_AUTO'])) {
        $autoconfig = $GLOBALS['AT_AUTO'];
        $auto = 1;
    }
    if (isset($GLOBALS['AT_THEME'])) {
        $themeconfig = $GLOBALS['AT_THEME'];
        $theme = 1;
    }
    if (!isset($auto) && !isset($theme)) {
        return false;
    }
    else {
        return array_merge($autoconfig, $themeconfig);
    }
}

function atGetBaseDir()
{
    return $_SERVER['DOCUMENT_ROOT']."/";
}

function atGetPlatform()
{
    if (isset($GLOBALS['mainfile']) && $GLOBALS['mainfile'] == 1) {
        $platform = "PHP-Nuke";
    }
    if (function_exists("pnConfigGetVar")) {
        $platform = pnConfigGetVar('Version_ID');
    }
    $platform = strtolower($platform);

    return $platform;
}

function atThemeAddHeader()
{
    $runningconfig = atGetRunningConfig();
    extract($runningconfig);

    extract($style);

	if (is_array($themeversion)) {
        extract($themeversion);
    }
    if (isset($stylesheet)) {
        if (@file_exists($themepath."style/$stylesheet") && !@is_dir($themepath."style/$stylesheet")) {
            $head .= "<link rel=\"StyleSheet\" href=\"".$themepath."style/$stylesheet\" type=\"text/css\">\n";
        }
    }
    if (eregi("ara", atGetLang()) || eregi("heb", atGetLang())) {
    	$head .= "<style type=\"text/css\">body { direction: rtl; text-align: right }</style>\n";
    }
    $head .= "<!-- IE fix -->\n"
    ."<style type=\"text/css\">form { display: inline }</style>\n";

    $head .= "\n<!--\n"
    ."************************* AutoTheme Lite .7 *************************\n"
    ."-->\n\n";

	if ($striphead) {
		$head .="</head>\n\n";
	}
    if ($include) {
        $head .= "<!--\n"
        ."*****************************************************************\n"
        ."Theme Name:  $thename\n"
        ."Version:     $version\n\n"
        ."Description: ".wordwrap($description, 60)."\n\n"
        ."Author:      $author\n"
        ."Contact:     $contact\n"
        ."*****************************************************************\n"
        ."-->\n";
    }
    atRunningSetVar("head", $head);
}

function atThemeAddFooter()
{
    $runningconfig = atGetRunningConfig();
    extract($runningconfig);

    $footer = "\n<!--\n"
    ."************************* AutoTheme Lite .7 *************************\n"
    ."-->\n\n";

    atRunningSetVar("footer", $footer);
}

?>
